@@ -18,8 +18,6 @@ import hashlib
 import inspect
 from unittest import mock
 
-import iso8601
-
 from oslo_versionedobjects import base
 from oslo_versionedobjects import exception
 from oslo_versionedobjects import fields
@@ -189,7 +187,7 @@ class TestObjectComparators(test.TestCase):
     def test_compare_obj_with_dt(self):
         mock_test = mock.Mock()
         mock_test.assertEqual = mock.Mock()
-        dt = datetime.datetime(1955, 11, 5, tzinfo=iso8601.iso8601.UTC)
+        dt = datetime.datetime(1955, 11, 5, tzinfo=datetime.timezone.utc)
         replaced_dt = dt.replace(tzinfo=None)
         my_obj = self.MyComparedObjectWithTZ(tzfield=dt)
         my_db_obj = {'tzfield': replaced_dt}
@@ -544,7 +542,7 @@ class TestObjectVersionChecker(test.TestCase):
         # bandit rule while py38 is in our supported runtimes.
         expected_hash = hashlib.md5(bytes(repr(
             expected_relevant_data).encode())).hexdigest()  # nosec
-        expected_fp = '{}-{}'.format(MyObject.VERSION, expected_hash)
+        expected_fp = f'{MyObject.VERSION}-{expected_hash}'
 
         self.assertEqual(expected_fp, fp, "_get_fingerprint() did not "
                                           "generate a correct fingerprint.")
@@ -576,7 +574,7 @@ class TestObjectVersionChecker(test.TestCase):
         # bandit rule while py38 is in our supported runtimes.
         expected_hash = hashlib.md5(bytes(repr(
             exp_relevant_data).encode())).hexdigest()  # nosec
-        expected_fp = '{}-{}'.format(MyObject.VERSION, expected_hash)
+        expected_fp = f'{MyObject.VERSION}-{expected_hash}'
 
         self.assertEqual(expected_fp, fp, "_get_fingerprint() did not "
                                           "generate a correct fingerprint.")
@@ -611,7 +609,7 @@ class TestObjectVersionChecker(test.TestCase):
         # bandit rule while py38 is in our supported runtimes.
         expected_hash = hashlib.md5(bytes(repr(
             exp_relevant_data).encode())).hexdigest()  # nosec
-        expected_fp = '{}-{}'.format(ExtraDataObj.VERSION, expected_hash)
+        expected_fp = f'{ExtraDataObj.VERSION}-{expected_hash}'
 
         self.assertEqual(expected_fp, fp, "_get_fingerprint() did not "
                                           "generate a correct fingerprint.")
